#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zenc
version:              0.1.2
visibility:           public
id:                   zenc-0.1.2-7qOfV6qnans4MLneHB1cLP
key:                  zenc-0.1.2-7qOfV6qnans4MLneHB1cLP
license:              BSD-3-Clause
copyright:            GHC HQ
maintainer:           dagitj@gmail.com
author:               GHC Team, Jason Dagit
synopsis:             GHC style name Z-encoding and Z-decoding
description:
    Implements GHC'\''s name mangling.  This code was taken
    directly from the GHC source.

category:             Text
abi:                  ec6a4c9067d9bfef84560e64897ab186
exposed:              True
exposed-modules:      Text.Encoding.Z
import-dirs:          /usr/lib/ghc-9.6.6/site-local/zenc-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/zenc-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/zenc-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zenc
hs-libraries:         HSzenc-0.1.2-7qOfV6qnans4MLneHB1cLP
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-zenc/html/zenc.haddock
haddock-html:         /usr/share/doc/haskell-zenc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

